pub enum DataError {
Expired,
Irreconcilable(CompetingProps),
NightPreviewInProgress,
}Variants
Expired
The object expired to enforce avoidance of race conditions.
Irreconcilable(CompetingProps)
Changed properties don’t harmonize with the condition of other properties.
NightPreviewInProgress
Night preview is currently active, because of other software or earlier use of this crate. The user could, e.g., right now be dragging the color tempature slider in the official Night Light settings.