pub enum Error {
IoError(Error),
ParseError(ParseError),
DataError(DataError),
}Variants
IoError(Error)
Error interacting with the registry, e.g., because of non-existent registry value. If the user never used Night Light in their OS installation, they should be advised to change something in the official settings to create the registry values and try again (turning Night Light on/off and moving the temperature slider should suffice).
ParseError(ParseError)
Couldn’t parse a byte stream.
DataError(DataError)
Couldn’t serialize the data from an instance into a byte stream.