ParseError

Enum ParseError 

pub enum ParseError {
    ExpectedConst(usize),
    ExpectedZero(usize),
    ExpectedInt(usize),
    ExpectedVlq64(usize),
    ValueNotInRange,
    InconsistentData,
    DataAfterExpectedEnd,
}

Variants



ExpectedConst(usize)

Expected certain bytes. This and some other variants bring the byte index with it where the respective item was expected, but not found.



ExpectedZero(usize)

Expected a zero-byte.



ExpectedInt(usize)

Expected an integer with a certain byte size (little endian).



ExpectedVlq64(usize)

Expected a VLQ (variable-length quantity) with a maximum of 64 data bits (little endian; possibly also zigzag-encoded).



ValueNotInRange

Encountered an exceptional value.



InconsistentData

Different parts of the data don’t harmonize with each other.



DataAfterExpectedEnd

Expected the end of the byte stream, but still found data.