pub enum Strictness {
Strict,
Lenient,
}Expand description
The mode of operation when parsing and checking values for validity.
Variants
Strict
Only accept known formats exact to the byte, and only value ranges last known to be valid. Should normally be used.
Lenient
Turn a blind eye regarding certain aspects when parsing or checking values for validity. Can be tried when strict mode doesn’t work, or when you must overcome certain limitations. Doesn’t influence serialization. Rather than this being used regularly, the parsing or other code should be updated.
Implementations
Sourceimpl Strictness
impl Strictness
pub fn from_lenient_bool(lenient: bool) -> Self
pub fn is_strict(&self) -> bool
pub fn is_lenient(&self) -> bool